%    Create a HTTP server that listens to a specific port and   
%    processes requests through the specified callback.   
%   
%    CALL:   
%        obj = Server(port, callback, <name values pairs>   
%   
%    INPUT:   
%        port: <integer>   
%          port on which the server is listening.   
%        callback: <function>   
%          (optional) if not specified the server does not process   
%          any requests. The signature of callback is   
%          callback(event), where "event" is an object of type   
%          modelit.web.server.HttpExchange. The function callback   
%          produces no output argument, but must use the method   
%          event.send when done.   
%        name values pairs: <[name,value]>   
%          additional attributes. acceptable parameters:   
%          hostname: <string>   
%            name of the host on which the server runs, e.g. localhost or the Docker container name.   
%          keystore: <string>   
%            (optional) filename of the .jks file.   
%          keystorepassword: <string>   
%            (optional) Password for the keystore.   
%        keymanagerpassword: <string>   
%          (optional) Password for the keymanager.   
%   
%    OUTPUT:   
%        obj: <modelit.web.server.Server>   
%          Server object. See methods('modelit.web.server.Server')   
%          for available methods.   
%   
%    EXAMPLE:   
%      Create a server and start it right away:   
%      modelit.web.server.Server(4444,@htmlCallback).start   
%   
%   
%  modelit.web.server.Server Properties:   
%    running  - Status of the server   
%    hostname - The hostname to which the server is listening   
%    port     - The port to which the server is listening   
%   
%  modelit.web.server.Server Methods:   
%    Server        - Create a HTTP server that listens to a specific port and processes requests through the specified callback.   
%    stop          - Stop the server.   
%    start         - Start the server to listen on the selected port.   
%    removeContext - Remove a callback for the specified path.   
%    addContext    - Add a callback for request on the specified port.   
%   
%  NOTE:   
%    Help automatically generated by classHelp (10-Mar-2023 23:08:04)   
   
   
% © Modelit 2006-2023   
% Matlab release: 2023a   
% Date: 2023/03/24 15:18:56   
