function testasync
% testasync - Example of asynchronous HTTP requests.
% 
% CALL:
%   testasync
% 
% INPUT:
%  No input required 
%
% OUTPUT:
%  No output

% Define the properties of the HTTP request.
% Use httpbin.org for testing.
% If an HTTP GET request is sent to: The https://httpbin.org/delay/3
% a response is returned with a 3 second delay.
METHOD = 'GET';
URL = 'https://httpbin.org/delay/3';

N = 4;

% Use the Matlab synchronous function. The Matlab execution thread is
% blocked until the request has completed.
webread(URL);

% Use the synchronous modelit.web.client.HttpRequest, the requests are made in order
% and similar to webread the Matlab execution thread is blocked until the
% request has completed
for i=1:N
    r = modelit.web.client.HttpRequest(METHOD, URL);
    fprintf('request %d sent\n', i);
    result = r.send;
    fprintf('request %d -> %d\n', i, result.getResponseCode());
end

% Use the asynchronous modelit.web.client.HttpRequest. By using the
% setCompletedCallback method, all requests are sent at once. The callbacks
% are triggered upon arrival (in random order) of the server's responses.
for i=1:N
    fprintf('request %d sent\n', i);
    r = modelit.web.client.HttpRequest(METHOD, URL);
    % Set the callback to be executed when the request has finished
    r.setCompletedCallback(@(result)completedCallback(i, result));
    r.send; % the result is handled by the completedCallback function.
end

%__________________________________________________________________________
function completedCallback(i, result)
% completedCallback - Callback triggered when the request has completed.
% 
% CALL:
%   completedCallback(i, result)
% 
% INPUT:
%   i: <int>
%     number of the request, for display purposes
%   result: <modelit.web.client.HttpResponse>
%     The response from the server
%
% OUTPUT:
%  No output

fprintf('request %d -> %d\n', i, result.getResponseCode());

 